@@ -438,7 +438,7 @@ class ArchivedArticles(Feed):
                     images = soup('img')
                     baseurl = entry["link"]
                     for img in images:
-                        filename = self.addImage(self.uniqueId, baseurl, img['src'])
+                        filename = self.addImage(configdir, self.uniqueId, baseurl, img['src'])
                         img['src']=filename
                     entry["contentLink"] = configdir+self.uniqueId+".d/"+id+".html"
                     file = open(entry["contentLink"], "w")
